@@ -8,9 +8,9 @@ use Module::Patch qw();
 use base qw(Module::Patch);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-02-06'; # DATE
+our $DATE = '2024-02-16'; # DATE
 our $DIST = 'Carp-Patch-Config'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 my @oldvals;
 our %config;
@@ -54,6 +54,12 @@ This is not an actual configuration for Carp, but a shortcut for:
         Data::Dump::ObjectAsString::dump($_[0]);
     };
 
+    # when value is 4 or 'Data::Dump::IfSmall'
+    $Carp::RefArgFormatter = sub {
+        require Data::Dump::IfSmall;
+        Data::Dump::IfSmall::dump($_[0]);
+    };
+
 _
             },
         },
@@ -62,7 +68,7 @@ _
             no warnings 'numeric';
             my $oldvals = {};
             for my $name (keys %config) {
-                my $carp_config_name = $name;
+                (my $carp_config_name = $name) =~ s/\A-//;
                 my $carp_config_val  = $config{$name};
                 if ($name =~ /\A-?Dump\z/) {
                     $carp_config_name = 'RefArgFormatter';
@@ -71,7 +77,8 @@ _
                         $config{$name} == 1   || $config{$name} eq 'Data::Dmp'                  ? sub { require Data::Dmp ; Data::Dmp::dmp  ($_[0]) } :
                         $config{$name} == 2   || $config{$name} eq 'Data::Dump'                 ? sub { require Data::Dump; Data::Dump::dump($_[0]) } :
                         $config{$name} == 3   || $config{$name} eq 'Data::Dump::ObjectAsString' ? sub { require Data::Dump::ObjectAsString; Data::Dump::ObjectAsString::dump($_[0]) } :
-                        die "Unknown value for -Dump, please choose 0/none, 1/Data::Dmp, 2/Data::Dump, 3/Data::Dump::ObjectAsString";
+                        $config{$name} == 4   || $config{$name} eq 'Data::Dump::IfSmall'        ? sub { require Data::Dump::IfSmall; Data::Dump::IfSmall::dump($_[0]) } :
+                        die "Unknown value for -Dump, please choose 0/none, 1/Data::Dmp, 2/Data::Dump, 3/Data::Dump::ObjectAsString, 4/Data::Dump::IfSmall";
                 }
                 $oldvals->{$carp_config_name} = ${"Carp::$carp_config_name"};
                 ${"Carp::$carp_config_name"} = $carp_config_val;
@@ -103,7 +110,7 @@ Carp::Patch::Config - Set some Carp variables
 
 =head1 VERSION
 
-This document describes version 0.007 of Carp::Patch::Config (from Perl distribution Carp-Patch-Config), released on 2022-02-06.
+This document describes version 0.008 of Carp::Patch::Config (from Perl distribution Carp-Patch-Config), released on 2024-02-16.
 
 =head1 SYNOPSIS
 
@@ -149,6 +156,12 @@ This is not an actual configuration for Carp, but a shortcut for:
      require Data::Dump::ObjectAsString;
      Data::Dump::ObjectAsString::dump($_[0]);
  };
+ 
+ # when value is 4 or 'Data::Dump::IfSmall'
+ $Carp::RefArgFormatter = sub {
+     require Data::Dump::IfSmall;
+     Data::Dump::IfSmall::dump($_[0]);
+ };
 
 
 =item * -MaxArgLen => int
@@ -194,13 +207,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2020, 2019, 2016 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2020, 2019, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
